diff --git a/test/integration/blocks.test.js b/test/integration/blocks.test.js
index 7f034c7dd8501023a9193ae0a7a2d0ec5c589082..1f7ab546a05f6ad57a308fe3f17991bd13de8c87 100644
--- a/test/integration/blocks.test.js
+++ b/test/integration/blocks.test.js
@@ -214,10 +214,10 @@ describe('Working with the blocks', () => {
     test('Adding costumes DOES update the default costume name in the toolbox', async () => {
         await loadUri(uri);
 
         // By default, costume1 is in the costume tab
         await clickText('Looks', scope.blocksTab);
         await driver.sleep(500); // Wait for scroll to finish
-        await clickText('costume1', scope.blocksTab);
+        await clickText('costume2', scope.blocksTab);
 
         // Also check that adding a new costume does update the list
         await clickText('Costumes');
@@ -214,10 +214,10 @@ describe('Working with the blocks', () => {
         await loadUri(uri);
 
-        // By default, costume1 is in the costume tab
+        // By default, costume2 is in the costume tab
         await clickText('Looks', scope.blocksTab);
         await driver.sleep(500); // Wait for scroll to finish